==> apimodule-1.0.5.tar.gz: lib/msimpersaa/response/issue_response.dart <==
class IssueResponse {
  bool con;
  String msg;
  List<IssueResults> results;

  IssueResponse({this.con, this.msg, this.results});

  IssueResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    if (json['results'] != null) {
      results = <IssueResults>[];
      json['results'].forEach((v) {
        results.add(IssueResults.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class IssueResults {
  int id;
  String jenisIssue;
  String nomor;
  String tanggalTerbit;
  String tanggalBerlaku;
  String penerbit;
  String documen;
  String pathFile;

  IssueResults(
      {this.id,
      this.jenisIssue,
      this.nomor,
      this.tanggalTerbit,
      this.tanggalBerlaku,
      this.penerbit,
      this.documen,
      this.pathFile});

  IssueResults.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    jenisIssue = json['jenis_issue'];
    nomor = json['nomor'];
    tanggalTerbit = json['tanggal_terbit'];
    tanggalBerlaku = json['tanggal_berlaku'];
    penerbit = json['penerbit'];
    documen = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = this.id;
    data['jenis_issue'] = this.jenisIssue;
    data['nomor'] = this.nomor;
    data['tanggal_terbit'] = this.tanggalTerbit;
    data['tanggal_berlaku'] = this.tanggalBerlaku;
    data['penerbit'] = this.penerbit;
    data['dokumen'] = this.documen;
    data['path_file'] = this.pathFile;
    return data;
  }
}

==> apimodule-1.0.6.tar.gz: lib/msimpersaa/response/issue_response.dart <==
class IssueResponse {
  bool con;
  String msg;
  List<IssueResults> results;

  IssueResponse({this.con, this.msg, this.results});

  IssueResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    if (json['results'] != null) {
      results = <IssueResults>[];
      json['results'].forEach((v) {
        results.add(IssueResults.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class IssueResults {
  int id;
  String jenisIssue;
  String nomor;
  String tanggalTerbit;
  String tanggalBerlaku;
  String penerbit;
  String document;
  String pathFile;

  IssueResults(
      {this.id,
      this.jenisIssue,
      this.nomor,
      this.tanggalTerbit,
      this.tanggalBerlaku,
      this.penerbit,
      this.document,
      this.pathFile});

  IssueResults.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    jenisIssue = json['jenis_issue'];
    nomor = json['nomor'];
    tanggalTerbit = json['tanggal_terbit'];
    tanggalBerlaku = json['tanggal_berlaku'];
    penerbit = json['penerbit'];
    document = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = this.id;
    data['jenis_issue'] = this.jenisIssue;
    data['nomor'] = this.nomor;
    data['tanggal_terbit'] = this.tanggalTerbit;
    data['tanggal_berlaku'] = this.tanggalBerlaku;
    data['penerbit'] = this.penerbit;
    data['dokumen'] = this.document;
    data['path_file'] = this.pathFile;
    return data;
  }
}
